Documentation
¶
Overview ¶
Additional Bucket types for more complex filtering
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllBucket ¶
Bucket that contains buckets - only returns true if all sub-buckets return true.
Buckets are tested in order, using short-circuiting behavior. This means that if an earlier bucket returns false, the ones after it will not be tested.
type AnyBucket ¶
Bucket that contains buckets - returns true if any sub-buckets return true.
Buckets are tested in order, using short-circuiting behavior. This means that if an earlier bucket returns true, the ones after it will not be tested.
type RejectContainsBucket ¶
type RejectContainsBucket string
func (RejectContainsBucket) Check ¶
func (b RejectContainsBucket) Check(url string) bool
type RejectExactBucket ¶
type RejectExactBucket string
func (RejectExactBucket) Check ¶
func (b RejectExactBucket) Check(url string) bool
type RejectPrefixBucket ¶
type RejectPrefixBucket string
func (RejectPrefixBucket) Check ¶
func (b RejectPrefixBucket) Check(url string) bool
type RejectSuffixBucket ¶
type RejectSuffixBucket string
func (RejectSuffixBucket) Check ¶
func (b RejectSuffixBucket) Check(url string) bool
Click to show internal directories.
Click to hide internal directories.